Codex class

Constructors

Codex({required CodexFunction decoder, required CodexFunction encoder})
const

Properties

decoder → CodexFunction
final
encoder → CodexFunction
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(dynamic value) → dynamic
encode(dynamic value) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited